package ch10_fileio.intro;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.StandardOpenOption;
import java.util.List;
import java.util.stream.Stream;

/**
 * Beispielprogramm für das Buch "Einfach Java"
 *
 * (C) 2021 Michael Inden
 */
public class FilesExample
{
    public static void main(final String[] args) throws IOException
    {
        final Path destinationFile = Files.createTempFile("WriteText", ".txt");
        final List<String> content = List.of("This", "is", "the", "content");

        // $\mbox{\bfseries Datei schreiben }$
        final Path resultFile = Files.write(destinationFile, content, StandardOpenOption.CREATE,
                                            StandardOpenOption.APPEND);

        // $\mbox{\bfseries Zeilen der Datei als Liste einlesen }$
        final List<String> contentLines = Files.readAllLines(resultFile);
        System.out.println(contentLines);

        // $\mbox{\bfseries Zeilen der Datei als Stream einlesen }$
        try (Stream<String> contentAsStream = Files.lines(resultFile))
        {
            contentAsStream.forEach(line -> System.out.println(line));
        }
    }
}