package ch12_date_and_time;

import static java.time.format.DateTimeFormatter.ofPattern;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Locale;

/**
 * Beispielprogramm für das Buch "Einfach Java"
 *
 * (C) 2021 Michael Inden
 */
public class DateTimeFormattingExample
{
    public static void main(final String[] args)
    {
        // $\mbox{\bfseries Definition einiger spezieller Formatter }$
        final DateTimeFormatter ddMMyyyyFormat = ofPattern("dd.MM.yyyy");
        final DateTimeFormatter italiandMMMMy = ofPattern("d.MMMM y", Locale.ITALIAN);

        // $\mbox{\bfseries Achtung: Die textuellen Teile sind in Hochkomma einzuschließen }$
        final String customPattern = "'Der 'dd'. Tag im 'MMMM' im Jahr 'yy'.'";
        final DateTimeFormatter customFormat = ofPattern(customPattern);

        System.out.println("Formatting:\n");
        final LocalDate february7th = LocalDate.of(1971, 2, 7);

        System.out.println("ddMMyyyyFormat: " + ddMMyyyyFormat.format(february7th));
        System.out.println("italiandMMMMy:  " + italiandMMMMy.format(february7th));
        System.out.println("customFormat:   " + customFormat.format(february7th));

        // $\mbox{\bfseries Parsen von Datumswerten }$  
        System.out.println("\nParsing:\n");

        final LocalDate fromIsoDate = LocalDate.parse("1971-02-07");
        final LocalDate fromddMMyyyyFormat = LocalDate.parse("18.03.2014", ddMMyyyyFormat);
        final LocalDate fromCustomFormat = LocalDate.parse("Der 31. Tag im Dezember im Jahr 19.", customFormat);

        System.out.println("From ISO Date:       " + fromIsoDate);
        System.out.println("From ddMMyyyyFormat: " + fromddMMyyyyFormat);
        System.out.println("From custom format:  " + fromCustomFormat);
    }
}
