package ch12_date_and_time.solutions;

import java.time.DayOfWeek;
import java.time.LocalDate;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * Beispielprogramm für das Buch "Java Challenge" / "Einfach Java"
 *
 * @author Michael Inden
 *
 * Copyright 2020/2021 by Michael Inden
 */
public class Ex03_Friday13thExample
{
    private Ex03_Friday13thExample()
    {
    }

    public static void main(String[] args)
    {
        System.out.println(friday13thGrouped(LocalDate.of(2013, 1, 1), LocalDate.of(2016, 1, 1)));        
    }
    
    static List<LocalDate> allFriday13th(final LocalDate start, final LocalDate end)
    {
        final Predicate<LocalDate> isFriday = day -> day.getDayOfWeek() ==
                        DayOfWeek.FRIDAY;
        final Predicate<LocalDate> is13th = day -> day.getDayOfMonth() == 13;

        final List<LocalDate> allFriday13th = start.datesUntil(end)
                        .filter(isFriday)
                        .filter(is13th)
                        .collect(Collectors.toList());
        return allFriday13th;
    }

    static Map<Integer, List<LocalDate>> friday13thGrouped(final LocalDate start,
                                                           final LocalDate end)
    {
        return new TreeMap<>(allFriday13th(start, end).stream().
                        collect(Collectors.groupingBy(LocalDate::getYear)));
    }
}
