package ch14_highscore_importer;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.ArrayList;
import java.util.List;

/**
 * Beispielprogramm für das Buch "Einfach Java"
 *
 * (C) 2021 Michael Inden
 */
public final class HighscoresCsvImporter
{
    public static List<Highscore> readHighscoresFromCsv(final String fileName)
    {
        final List<Highscore> highscores = new ArrayList<>();

        try
        {
            final List<String> lines = Files.readAllLines(Paths.get(fileName), StandardCharsets.ISO_8859_1);

            for (String line : lines)
            {
                if (!isEmptyLineOrComment(line))
                {
                    try
                    {
                        Highscore highscore = extractHighscoreFrom(line);
                        highscores.add(highscore);
                    }
                    catch (final IllegalArgumentException e)
                    {
                        System.err.println("Skipping invalid point or level value '" + line + "'");
                    }
                }
            }
        }
        catch (final IOException e)
        {
            System.err.println("processing of file '" + fileName + "' failed: " + e);
        }

        return highscores;
    }

    private static boolean isEmptyLineOrComment(final String line)
    {
        return line.isBlank() || line.stripLeading().startsWith("#");
    }

    // ...

    private static Highscore extractHighscoreFrom(final String line) throws IllegalArgumentException
    {
        final int VALUE_COUNT = 3;

        // Spalte die Eingabe mit ';' oder ',' auf           
        final String[] values = line.split(";|,");

        //  $\mbox{\bfseries Behandlung von unvollständigen Einträgen  }$
        if (values.length != VALUE_COUNT)
        {
            throw new IllegalArgumentException("invalid line");
        }

        // $\mbox{\bfseries Auslesen der Werte als String + Typprüfung }$
        final String name = values[0].trim();
        final int points = Integer.parseInt(values[1].strip());
        final int level = Integer.parseInt(values[2].strip());

        return new Highscore(name, points, level);
    }

    public static void main(String[] args)
    {
        System.out.println(readHighscoresFromCsv("Highscores.csv"));
    }
}